@@ -2,10 +2,11 @@
 #'
 #'This function computes an approximation of the Variance Component test for a
 #'mixture of \eqn{\chi^{2}}s using permutations. This is preferable to the
-#'asymptotic approximation for small sample sizes.
+#'asymptotic approximation for small sample sizes. We rely on exact p-values following
+#'Phipson and Smyth, 2010 (see References).
 #'
 #'
-#'@param y a numeric matrix of dim \code{g x n} containing the raw RNA-seq counts for g
+#'@param y a numeric matrix of dim \code{G x n} containing the raw RNA-seq counts for G
 #'genes from \code{n} samples.
 #'
 #'@param x a numeric design matrix of dim \code{n x p} containing the \code{p} covariates
@@ -35,6 +36,11 @@
 #'@param na.rm logical: should missing values (including \code{NA} and \code{NaN})
 #'be omitted from the calculations? Default is \code{FALSE}.
 #'
+#'@references Phipson B, and Smyth GK (2010). Permutation p-values should never be zero:
+#'calculating exact p-values when permutations are randomly drawn. \emph{Statistical Applications
+#'in Genetics and Molecular Biology}, Volume 9, Issue 1, Article 39.
+#'\url{http://www.statsci.org/smyth/pubs/PermPValuesPreprint.pdf}
+#'
 #'@return A list with the following elements when the set p-value is computed :\itemize{
 #'   \item \code{set_score_obs}: the approximation of the observed set score
 #'   \item \code{set_pval}: the associated set p-value
@@ -76,8 +82,8 @@
 #'@importFrom CompQuadForm davies
 #'
 #'@export
-vc_test_perm <- function(y, x, indiv=rep(1,nrow(x)), phi, w, Sigma_xi = diag(ncol(phi)),
-                         n_perm=1000, genewise_pvals=FALSE, homogen_traj=FALSE,
+vc_test_perm <- function(y, x, indiv = rep(1,nrow(x)), phi, w, Sigma_xi = diag(ncol(phi)),
+                         n_perm = 1000, genewise_pvals = FALSE, homogen_traj = FALSE,
                          na.rm = FALSE){
 
   n_samples <- ncol(y)
@@ -92,21 +98,33 @@ vc_test_perm <- function(y, x, indiv=rep(1,nrow(x)), phi, w, Sigma_xi = diag(nco
     vc_score_2use <- vc_score_perm
   }
 
+  if(is.null(indiv)){
+    options(warn = -1)
+    N_possible_perms <- factorial(ncol(y))
+    options(warn = 0)
+  }else{
+    options(warn = -1)
+    N_possible_perms <- prod(sapply(table(indiv), factorial))
+    options(warn = 0)
+  }
+
+
   score_list_res <- vc_score_2use(y = y, x = x, indiv = indiv_fact, phi = phi, w = w,
                                   Sigma_xi = Sigma_xi, na_rm = na.rm, n_perm = n_perm)
 
-
   if(genewise_pvals){
     gene_scores_obs <- score_list_res$gene_scores_unscaled
     gene_scores_perm <- score_list_res$gene_scores_unscaled_perm
-    #pvals <- 1 - rowMeans(sapply(gene_scores_perm, function(x){x < gene_scores_obs}))
-    pvals <- 1 - rowMeans(gene_scores_perm < gene_scores_obs)
-    #hist(pvals)
-    ds_fdr <- dsFDR(gene_scores_perm, gene_scores_obs, n_perm, doPlot=FALSE, use_median=TRUE)
-    ans <- list("gene_scores_obs" = gene_scores_obs,"gene_pvals" = pvals, "fdr" = ds_fdr)
-  }else{
-    pval <- 1-sum(score_list_res$scores_perm < score_list_res$score)/n_perm
-    ans <- list("set_score_obs" = score_list_res$score, "set_pval" = pval)
-  }
 
+    nprem_supobs <- rowSums(gene_scores_perm >= gene_scores_obs)
+
+    #pvals_naive <- nprem_supobs/n_perm
+    #pvals_u <- (nprem_supobs + 1)/(n_perm +1)
+    pvals_e <- perm_pe(nprem_supobs, nperm_eff = n_perm, total_possible_nperm = N_possible_perms)
+    ans <- list("gene_scores_obs" = gene_scores_obs, "gene_pvals" = pvals_e)
+  }else{
+    pvals_u <- (sum(score_list_res$scores_perm >= score_list_res$score) + 1)/(n_perm + 1)
+    ans <- list("set_score_obs" = score_list_res$score, "set_pval" = pvals_u)
+
+  }
 }
